@@ -12,22 +12,24 @@
 #' coordinate to map.
 #'
 #' @export
-#' @examples \dontrun{
-#'  nearest_cyclestreets(53, 0.02, pat = Sys.getenv("CYCLESTREET"))
-#'  nearest_cyclestreets(cents[1, ], pat = Sys.getenv("CYCLESTREET"))
-#'  nearest_cyclestreets(cents_sf[1, ], pat = Sys.getenv("CYCLESTREET"))
+#' @examples
+#' \dontrun{
+#' nearest_cyclestreets(53, 0.02, pat = Sys.getenv("CYCLESTREET"))
+#' nearest_cyclestreets(cents[1, ], pat = Sys.getenv("CYCLESTREET"))
+#' nearest_cyclestreets(cents_sf[1, ], pat = Sys.getenv("CYCLESTREET"))
 #' }
 nearest_cyclestreets <- function(shp = NULL, lat, lng, pat = api_pat("cyclestreet")) {
   UseMethod("nearest_cyclestreets", object = shp)
 }
 #' @export
 nearest_cyclestreets.NULL <- function(shp = NULL, lat, lng, pat = api_pat("cyclestreet")) {
-  url = paste0("https://api.cyclestreets.net/v2/nearestpoint?lonlat=", lng, ",", lat, "&key=", pat)
-  obj = jsonlite::fromJSON(url)
-  coords = obj$features$geometry$coordinates[[1]]
-  sp::SpatialPointsDataFrame(coords = matrix(coords, ncol = 2),
-                         data = data.frame(orig_lat = lat, orig_lng = lng))
-
+  url <- paste0("https://api.cyclestreets.net/v2/nearestpoint?lonlat=", lng, ",", lat, "&key=", pat)
+  obj <- jsonlite::fromJSON(url)
+  coords <- obj$features$geometry$coordinates[[1]]
+  sp::SpatialPointsDataFrame(
+    coords = matrix(coords, ncol = 2),
+    data = data.frame(orig_lat = lat, orig_lng = lng)
+  )
 }
 #' @export
 nearest_cyclestreets.Spatial <- function(shp, lat = shp@coords[1, 2], lng = shp@coords[1, 1], pat = api_pat("cyclestreet")) {
